Structured multicospan (open system with multiple legs/feet)
Source:R/structured_cospans.R
StructuredCospan.RdRepresents an open ACSet: an apex with multiple legs mapping discrete feet into the apex. Each leg identifies which parts of the apex are "exposed" at that interface.
Arguments
- apex
The ACSet forming the cospan apex
- legs
List of ACSetTransformation objects from discrete feet to apex
- interface_ob
Name of the object type used for interfaces