Create a discrete (empty) ACSet with n parts in a given object
Source:R/structured_cospans.R
discrete_acset.RdThe L functor: FinSet -> ACSet maps a finite set of size n to an ACSet with n parts in the interface object and nothing else.
R/structured_cospans.R
discrete_acset.RdThe L functor: FinSet -> ACSet maps a finite set of size n to an ACSet with n parts in the interface object and nothing else.